#
# spec file for package fsvs
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fsvs
Version:        1.2.9
Release:        2.3
Summary:        Backup/Restore/Versioning of large Data Sets with Meta-Data
License:        GPL-3.0-or-later
Group:          Productivity/Archiving/Backup
URL:            http://fsvs.tigris.org/
Source:         https://download.fsvs-software.org/fsvs-%{version}.tar.bz2
Patch1:         fsvs-destdir.patch
Patch2:         fsvs-1.2.5-linking.patch
# PATCH-FIX-UPSTREAM -- TODO
Patch3:         reproducible.patch
BuildRequires:  apache2-devel
BuildRequires:  ctags
BuildRequires:  db-devel
BuildRequires:  ed
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gdbm
BuildRequires:  gdbm-devel
BuildRequires:  glibc-devel
BuildRequires:  libapr-util1-devel
BuildRequires:  libapr1-devel
BuildRequires:  make
BuildRequires:  neon-devel
BuildRequires:  openldap2-devel
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  subversion-devel
BuildRequires:  zlib-devel

%description
FSVS is the abbreviation for “Fast System VerSioning”, and is pronounced
[fisvis].

It is a complete backup/restore/versioning tool for all files in a directory
tree or whole filesystems, with a subversionTM repository as the backend.

You may think of it as some kind of tar or rsync with versioned storage.

%prep
%setup -q
%patch -P 1
%patch -P 2
%patch -P 3 -p1

%build
export CFLAGS="%{optflags} $(pkg-config --includes apr-1)"
export CFLAGS="$CFLAGS -fno-strict-aliasing -fgnu89-inline"
%configure --disable-silent-rules
%make_build

%install
%make_install

rm -rf doc/develop
echo -n >manfiles.lst
for p in doc/*.{1,5}; do
    f="${p##*/}"
    m="${f##*.}"
    install -D -m0644 "$p" "%{buildroot}%{_mandir}/man${m}/${f}"
    rm "$p"
    echo "%doc %{_mandir}/man${m}/${f}"'*' >>manfiles.lst
done

%files -f manfiles.lst
%license LICENSE
%doc doc CHANGES README
%{_bindir}/fsvs

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.2.9:
  - Various small fixes that got visible with new compiler versions and/or LLVM.
  - Fixed URI canonicalization (UTF8)
- refreshed patches fsvs-1.2.5-linking.patch, fsvs-destdir.patch
* Sat May 27 2017 bwiedemann@suse.com
- Update to 1.2.7
  * Updates for GCC 5 and Clang
- Rebase fsvs-1.2.5-linking.patch
- Add reproducible.patch to sort input files to make build reproducible
  (boo#1041090)
* Mon Jun 22 2015 antoine.belvire@laposte.net
- Update to 1.2.5:
  * bugfix: auto-props not applied for explicitly specified entries.
    Please note that the auto-props _only_ get applied if there are
    _no_ properties on an entry set (yet); so, after fsvs prop-set
    file property... the auto-props will _not_ be applied (as they
    might overwrite the manually set properties).
  * compilation fixes for MacOS 10.6 (1.2.4)
  * added "password" option (1.2.4)
  * workarounds for gcc-4.5 and gcc-4.6 regressions (1.2.4)
  * compatibility with autoconf 2.68 (1.2.4)
- Rebase fsvs-1.2.3-linking.patch into fsvs-1.2.5-linking.patch
- Remove gcc46.diff (upstreamed).
- Fix build with GCC 5: add -fgnu89-inline to CFLAGS.
* Thu Dec  8 2011 coolo@suse.com
- "GPL" is not a valid spdx license
* Wed Aug 31 2011 crrodriguez@opensuse.org
- Fix linking.
* Thu Jul 21 2011 dmueller@suse.de
- update to 1.2.3:
  * Fix length calculation bug, found by Mark via a (bad?) compilation warning.
  Thank you!
* Sat Mar 13 2010 pascal.bleser@opensuse.org
- update to 1.2.2:
  * documentation fixes
  * fixed config_dir, so that using other authentication paths work (previously $CONF/auth was fixed; better default)
  * fix "unversion" on the wc root
  * fix "." as only parameter when started from the root
  * fix SIGPIPE handling
  * don't do the "_base" symlink; it breaks eg. "grep -r /etc" -- write a readme instead
  * fix ENOMEM because of still mapped file data
  * new option "dir_exclude_mtime"
- changes from 1.2.1:
  * documentation updates
  * fixed some small bugs
  * the secondary URL/revision file doesn't have to exist
  * fix recursive behaviour of "_build-new-list"
  * now supports arbitrary "svn+" tunnels, like subversion does
  * "fsvs log -v" for now filters the changed entries list, and shows the paths relative to the parameter
  * fixed "-o verbose=all" output; would be interpreted as "totally silent" because of signed compares
  * better out-of-date messages
  * compatibility fixes for subversion 1.6.4
  * fix tempfile being left after FSVS run
  * bugfix: on commit empty property hashes got created
  * bugfix for selection of entries (filter bit)
  * bugfixes for non-UTF8 locales and update/sync
* Fri Jul 17 2009 pascal.bleser@opensuse.org
- update to 1.2.0
- fixed spec file
* Fri Dec 12 2008 poeml@suse.de
- build 1.1.17 on all repos.
